@@ -1,8 +1,8 @@
 # coding: utf-8
 
-VERSION = (1, 19, 23)
-CODENAME = "usernames"
-BUILD_DT = (2025, 12, 17)
+VERSION = (1, 20, 3)
+CODENAME = "sftp is fine too"
+BUILD_DT = (2026, 1, 21)
 
 S_VERSION = ".".join(map(str, VERSION))
 S_BUILD_DT = "{0:04d}-{1:02d}-{2:02d}".format(*BUILD_DT)
